version 15

clear all

local directory = ""
local folder = "`directory'" + "Replication/Data"
cd "`folder'"

* JCS Appeals Court Scores
use "JCS appeals.dta"
replace name = "Sotomayor, Sonia Maria" if name == "Sotomayor, Sonia"
replace name = "Harlan, John Marshall (II)" if name == "Harlan, John Marshall"
replace name = "Kennedy, Anthony McLeod" if name == "Kennedy, Anthony McCleod"
replace name = "Roberts, John G., Jr." if name == "Roberts, John"

* Justices Data (to get Name ID)
merge 1:m name using justicesdata.dta, keep(master match) keepusing(spaethid prespart) nogenerate

* Remove Duplicate Nominations
bysort name spaethid: keep if _n == 1

rename spaethid justice

* Supreme Court Ideology Scores
merge m:1 justice using "../Output/Estimates/justice_ols_coef_merge_1a.dta", keepusing(justice_FE_1a) keep(master match) nogenerate
label variable justice_FE_1a "Model 1 Ideology Estimates" 


** Relationship between JCS and Ideology Score
* Garland Nomination Data
replace prespart = 1 if name == "Garland, Merrick"
* Gorsuch Nominationa Data
replace prespart = 6 if name == "Gorsuch, Neil"
* Kavanaugh Nomination Data
replace prespart = 6 if name == "Kavanaugh, Brett"

reg justice_FE_1a i.prespart JCS, r

predict forecast_ideology, xb

* Scalia Vacancy
summarize forecast_ideology if name == "Garland, Merrick"
local garland = `r(mean)'

summarize forecast_ideology if name == "Gorsuch, Neil"
local gorsuch = `r(mean)'

summarize justice_FE_1a if name == "Scalia, Antonin"
local scalia = `r(mean)'

local garland_diff = `garland' - `scalia'
local garland_effect = `garland_diff' * 1/8 * 1.131
display `garland_effect'

local gorsuch_diff = `gorsuch' - `scalia'
local gorsuch_effect = `gorsuch_diff' * 1/8 * 1.131
display `gorsuch_effect'

* Kennedy Vacancy
summarize forecast_ideology if name == "Kavanaugh, Brett"
local kavanaugh = `r(mean)'

summarize justice_FE_1a if name == "Kennedy, Anthony McLeod"
local kennedy = `r(mean)'

local kavanaugh_diff = `kavanaugh' - `kennedy'
local kavanaugh_effect = `kavanaugh_diff' * 1/8 * 1.131
display `kavanaugh_effect'

* Ginsburg Vacancy
local barrett = `scalia'

summarize justice_FE_1a if name == "Ginsburg, Ruth Bader"
local ginsburg = `r(mean)'

local barrett_diff = `barrett' - `ginsburg'
local barrett_effect = `barrett_diff' * 1/8 * 1.131
display `barrett_effect'

* Summary
display `garland_effect'
display `gorsuch_effect'
display `kavanaugh_effect'
display `barrett_effect'

